#!/bin/sh
#
# rc.M		This file is executed by init(8) when the system is being
#		initialized for one of the "multi user" run levels (i.e.
#		levels 1 through 6).  It usually does mounting of file
#		systems et al.
#
# Version:	@(#)/etc/rc.d/rc.M	2.02	02/26/93
#
# Author:	Fred N. van Kempen, <waltje@uwalt.nl.mugnet.org>
#		Heavily modified by Patrick Volkerding <volkerdi@ftp.cdrom.com>
#

# Tell the viewers what's going to happen...
echo "Going multiuser..."

# Update all the shared library links automatically
/sbin/ldconfig

# Screen blanks after 15 minutes idle time.
/bin/setterm -blank 15


# Look for a CD-ROM in a CD-ROM drive, and if one is found,
# mount it under /cdrom.  This must happen before any of the
# binaries on the CD are needed.
#
# If you don't have a CD-ROM and want to disable this, set the
# /etc/rc.d/rc.cdrom permissions to non-executable: chmod 644 /etc/rc.d/rc.cdrom
# 
if [ -x /etc/rc.d/rc.cdrom ]; then
  . /etc/rc.d/rc.cdrom
fi

# Initialize the NET subsystem.
if [ -x /etc/rc.d/rc.inet1 ]; then
  . /etc/rc.d/rc.inet1
  . /etc/rc.d/rc.inet2
else
  if [ -x /usr/sbin/syslogd ]; then
    /usr/sbin/syslogd
    sleep 1 # Prevents a race condition with SMP kernels
    /usr/sbin/klogd
  fi
  if [ -x /usr/sbin/lpd ]; then
    /usr/sbin/lpd
  fi
fi

# Start netatalk. (a file/print server for Macs using Appletalk)
#if [ -x /etc/rc.d/rc.atalk ]; then
#  /etc/rc.d/rc.atalk
#fi

# Start crond (Dillon's crond):
# If you want cron to actually log activity to /var/adm/cron, then change
# -l10 to -l8 to increase the logging level.
/usr/sbin/crond -l10 >>/var/adm/cron 2>&1

# Remove stale locks and junk files (must be done after mount -a!)
/bin/rm -f /var/spool/locks/* /var/lock/* /var/spool/uucp/LCK..* /tmp/.X*lock /tmp/core /core 1> /dev/null 2> /dev/null

# Remove stale hunt sockets so the game can start.
if [ -r /tmp/hunt -o -r /tmp/hunt.stats ]; then
  echo "Removing your stale hunt sockets from /tmp..."
  /bin/rm -f /tmp/hunt*
fi

# Ensure basic filesystem permissions sanity.
chmod 755 /
chmod 1777 /tmp /var/tmp


# Start the sendmail daemon:
#if [ -x /usr/sbin/sendmail ]; then
#  echo "Starting sendmail daemon (/usr/sbin/sendmail -bd -q15m)..."
#  /usr/sbin/sendmail -bd -q15m
#fi

# Start the postfix
#if [ -x /usr/sbin/postfix ]; then
#  echo "Starting postfix ..."
#  /usr/sbin/postfix start
#fi

# Start the bind9
#if [ -x /usr/sbin/named ]; then
#  echo "Starting named ..."
#  /usr/sbin/named -c /var/named/named.conf -t /var/named -u named -n `/usr/bin/grep proce
#ssor /proc/cpuinfo | /usr/bin/wc -l`
#fi

# Start the APM daemon if APM is enabled in the kernel:
#if [ -x /usr/sbin/apmd ]; then
#  if cat /proc/apm 1> /dev/null 2> /dev/null ; then
#    echo "Starting APM daemon..."
#    /usr/sbin/apmd
#  fi
#fi

# Load a custom screen font if the user has an rc.font script.
if [ -x /etc/rc.d/rc.font ]; then
  . /etc/rc.d/rc.font
fi

# iBCS Emulation for Linux
# The Intel Binary Compatibility Specification, or iBCS, specifies the
# interfaces between application programs and the surrounding operating
# system environment for i386 based systems. There are however several
# flavours of iBCS in use - SVR4, SVR3 plus several vendor specific
# extensions to SVR3 which are slightly different and incompatible. The
# iBCS emulator for Linux supports all flavours known so far.
if [ -x /etc/rc.d/rc.ibcs2 ]; then
  . /etc/rc.d/rc.ibcs2
fi

# Start at daemon(atd)
if [ -x /usr/sbin/atd ]; then
  /usr/sbin/atd
fi

# Start Web server:
if [ -x /etc/rc.d/rc.httpd ]; then
  . /etc/rc.d/rc.httpd
fi

# Start Samba (a file/print server for Win95/NT machines):
if [ -x /etc/rc.d/rc.samba ]; then
  . /etc/rc.d/rc.samba
fi

# Load a custom keymap if the user has an rc.keymap script.
if [ -x /etc/rc.d/rc.keymap ]; then
  . /etc/rc.d/rc.keymap
fi

if [ -d /proc/asound ] ; then
  modprobe snd-pcm-oss
  modprobe snd-seq-oss
  if [ -f /etc/asound.state ] ; then
    /usr/sbin/alsactl restore
  else
    /usr/bin/aumix -q -v75 -w75 -c75
  fi
fi

# run the startup scripts in /etc/rc.d/init.d
if [ -d /etc/rc.d/init.d ]; then
  EXCLUDELIST=""
  for i in /etc/rc.d/rc.* ; do
    if [ -h $i -a -f $i ] ; then
      EXCLUDE="`ls -l $i|grep "init\.d/"|sed -e 's|.*init\.d/||'`"
      if [ ! "$EXCLUDE" = "" ] ; then
        EXCLUDELIST="$EXCLUDELIST -e $EXCLUDE"
      fi
    fi
  done
  if [ "$EXCLUDELIST" = "" ] ; then
    INITDLIST="`ls /etc/rc.d/init.d`"
  else
    INITDLIST="`ls /etc/rc.d/init.d|grep -v $EXCLUDELIST`"
  fi
  for i in $INITDLIST ; do
    if [ -x /etc/rc.d/init.d/$i ] ; then
      /etc/rc.d/init.d/$i start
    fi
  done
  #for i in /etc/rc.d/init.d/*; do
  #  if [ -x $i -a ! -x /etc/rc.d/rc.${i##*/} ] ; then
  #    $i start
  #  fi
  #done
fi

# Start the local setup procedure.
if [ -x /etc/rc.d/rc.local ]; then
  . /etc/rc.d/rc.local
fi

# run the initpkg scripts if they still exits
. /etc/rc.d/rc.initpkg

# All done.
